@@ -3,7 +3,7 @@ from snapshottest import TestCase
 from rescape_python_helpers.functional.ramda import to_dict_deep, all_pass_dict, flatten_dct, map_keys_deep, \
     map_with_obj_deep, pick_deep, unflatten_dct, fake_lens_path_view, key_string_to_lens_path, props, \
     fake_lens_path_set, index_by, props_or, str_paths_or, chain_with_obj_to_values, one_unique_or_raise, \
-    flatten_dct_until, pick
+    flatten_dct_until, pick, unique_by
 from . import ramda as R
 
 
@@ -275,10 +275,10 @@ class TestRamda(TestCase):
     def test_str_paths_or(self):
         result = str_paths_or(
             'undefined',
-            ['panda.myr', 'smook', 'panda.beite', 'panda.seter', 'avfall'],
-            dict(panda=dict(myr=None, beite='tasty', seter='sleepy'), avfall='dirty')
+            ['panda.myr', 'smook', 'panda.beite', 'panda.seter', 'avfall', 'panda.george.2.1'],
+            dict(panda=dict(myr=None, beite='tasty', seter='sleepy', george=[0, 1, [0, 2]]), avfall='dirty')
         )
-        assert result == [None, 'undefined', 'tasty', 'sleepy', 'dirty']
+        assert result == [None, 'undefined', 'tasty', 'sleepy', 'dirty', 2]
 
     def test_index_by(self):
         assert index_by(
@@ -326,3 +326,19 @@ class TestRamda(TestCase):
             test,
             '__'
         ) == {'data__streets': ['Somehood']}
+
+    def test_unique_by(self):
+        objs = [{'question': 'ask'},
+                {'question': 'me'},
+                {'question': 'if'},
+                {'question': 'Im'},
+                {'question': 'an'},
+                {'question': 'apple'},
+                {'question': 'an'},
+                {'question': 'apple'},
+                {'question': 'ask'},
+                {'question': 'if'},
+                {'question': 'Im'},
+                {'question': 'me'}
+                ]
+        assert R.length(unique_by(R.prop('question'), objs)) == 6
